NAME
IWL::Checkbox - a checkbox
INHERITANCE
IWL::Object -> IWL::Widget -> IWL::Input -> IWL::Checkbox
DESCRIPTION
The checkbox provides a checkbox most commonly used in forms.
CONSTRUCTOR
IWL::Checkbox->new ([%ARGS])
Where %ARGS is an optional hash parameter with with key-values.
- checked
-
Set to true if the checkbox should be checked on default
- label
-
Set the label of the checkbox
METHODS
- setLabel (TEXT)
-
Sets the text of the checkbox label
Parameter: TEXT - the text.
- getLabel
-
Gets the text of the checkbox label
- setChecked (BOOL)
-
Sets whether the checkbox is checked or not
Parameter: BOOL - a boolean value.
- isChecked
-
Returns true if the checkbox is checked, false otherwise.
- extractState (STATE)
-
Update the IWL::Stash(3pm) STATE according to the input state.
- applyState (STATE)
-
Update the input element according to the IWL::Stash(3pm) STATE object. The STATE will get modified, i.e. the "used" element will be shifted from the according slot (name attribute) of the state.
LICENCE AND COPYRIGHT
Copyright (c) 2006-2007 Viktor Kojouharov. All rights reserved.
This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself. See perldoc perlartistic.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
1 POD Error
The following errors were encountered while parsing the POD:
- Around line 229:
You forgot a '=back' before '=head1'